# TOPSIS Package

Multiple Criteria Decision Making (MCDM) using TOPSIS
Assignment 04

## Installation

`pip install Topsis-Abhay-101903014`

## How to use it?

Once installed you can simply use it from command line.

`python <programName> <input.csv> <weights array> <impacts array> <output.csv>`

## License

© 2022 Abhay (Roll Number: 101903014)

This repository is licensed under the MIT license. See LICENSE for details.
